==> haskell-monadrandom-0.5.2-37-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monadrandom.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 MonadRandom
version:              0.5.2
visibility:           public
id:                   MonadRandom-0.5.2-KdIvhwAO45D55r7qHudmPQ
key:                  MonadRandom-0.5.2-KdIvhwAO45D55r7qHudmPQ
license:              BSD-3-Clause
maintainer:           Brent Yorgey <byorgey@gmail.com>
author:               Cale Gibbard and others
synopsis:             Random-number generation monad.
description:          Support for computations which consume random values.
category:             Control
abi:                  ef3ff65ff8e280e8b456e00994e6ad32
exposed:              True
exposed-modules:
    Control.Monad.Random Control.Monad.Random.Class
    Control.Monad.Random.Lazy Control.Monad.Random.Strict
    Control.Monad.Trans.Random Control.Monad.Trans.Random.Lazy
    Control.Monad.Trans.Random.Strict

import-dirs:          /usr/lib/ghc-8.10.3/site-local/MonadRandom-0.5.2
library-dirs:         /usr/lib/ghc-8.10.3/site-local/MonadRandom-0.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/MonadRandom-0.5.2
hs-libraries:         HSMonadRandom-0.5.2-KdIvhwAO45D55r7qHudmPQ
depends:
    base-4.14.1.0 mtl-2.2.2 primitive-0.7.1.0-FWMrJqGiHZ5CFbN5KoTYOo
    random-1.2.0-5N9o8Kb3o8bGdaMXJMpyqT transformers-0.5.6.2
    transformers-compat-0.6.6-5ZJJ9POl5DGLIWTn4Z8HjM

haddock-interfaces:   /usr/share/doc/haskell-monadrandom/html/MonadRandom.haddock
haddock-html:         /usr/share/doc/haskell-monadrandom/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monadrandom-0.5.2-42-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monadrandom.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 MonadRandom
version:              0.5.2
visibility:           public
id:                   MonadRandom-0.5.2-Lho664X8m5kAasZkxF03Di
key:                  MonadRandom-0.5.2-Lho664X8m5kAasZkxF03Di
license:              BSD-3-Clause
maintainer:           Brent Yorgey <byorgey@gmail.com>
author:               Cale Gibbard and others
synopsis:             Random-number generation monad.
description:          Support for computations which consume random values.
category:             Control
abi:                  d004c700292089fe9450ee1c64835c4b
exposed:              True
exposed-modules:
    Control.Monad.Random Control.Monad.Random.Class
    Control.Monad.Random.Lazy Control.Monad.Random.Strict
    Control.Monad.Trans.Random Control.Monad.Trans.Random.Lazy
    Control.Monad.Trans.Random.Strict

import-dirs:          /usr/lib/ghc-8.10.3/site-local/MonadRandom-0.5.2
library-dirs:         /usr/lib/ghc-8.10.3/site-local/MonadRandom-0.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/MonadRandom-0.5.2
hs-libraries:         HSMonadRandom-0.5.2-Lho664X8m5kAasZkxF03Di
depends:
    base-4.14.1.0 mtl-2.2.2 primitive-0.7.1.0-Lv6PNgiQvA0Ky6DJvjsHti
    random-1.2.0-52OpOPhBQ1G1x1onrVvBUa transformers-0.5.6.2
    transformers-compat-0.6.6-5ZJJ9POl5DGLIWTn4Z8HjM

haddock-interfaces:   /usr/share/doc/haskell-monadrandom/html/MonadRandom.haddock
haddock-html:         /usr/share/doc/haskell-monadrandom/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
